import React from 'react'
import { shallow } from 'enzyme'
import ChallengeCard from './ChallengeCard'
import ChallengeCardLocked from './ChallengeCardLocked'
import ChallengeCardUnlocked from './ChallengeCardUnlocked'
import ChallengeCardOnGoing from './ChallengeCardOnGoing'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockMoveToSlide = jest.fn()

describe('ChallengeCard component', () => {
  it('should be rendered correctly', () => {
    const component = shallow(
      <ChallengeCard
        userChallenge={userChallengeData[1]}
        indexSlider={0}
        index={0}
        cardWidth={200}
        cardHeight={400}
        moveToSlide={mockMoveToSlide}
      />
    ).getElement()
    expect(component).toMatchSnapshot()
  })
  it('should render locked Card', () => {
    const wrapper = shallow(
      <ChallengeCard
        userChallenge={userChallengeData[4]}
        indexSlider={0}
        index={0}
        cardWidth={200}
        cardHeight={400}
        moveToSlide={mockMoveToSlide}
      />
    )
    expect(wrapper.find(ChallengeCardLocked).exists()).toBeTruthy()
  })
  it('should render unlocked Card', () => {
    const wrapper = shallow(
      <ChallengeCard
        userChallenge={userChallengeData[3]}
        indexSlider={0}
        index={0}
        cardWidth={200}
        cardHeight={400}
        moveToSlide={mockMoveToSlide}
      />
    )
    expect(wrapper.find(ChallengeCardUnlocked).exists()).toBeTruthy()
  })
  it('should render ongoing Card', () => {
    const wrapper = shallow(
      <ChallengeCard
        userChallenge={userChallengeData[2]}
        indexSlider={0}
        index={0}
        cardWidth={200}
        cardHeight={400}
        moveToSlide={mockMoveToSlide}
      />
    )
    expect(wrapper.find(ChallengeCardOnGoing).exists()).toBeTruthy()
  })
})
