/* eslint-disable react/display-name */
import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../../tests/__mocks__/globalStateData.mock'
import ErrorPage from './ErrorPage'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

jest.mock('components/Header/Header', () => () => <div id="Header" />)
jest.mock('components/Header/CozyBar', () => () => <div id="CozyBar" />)
// eslint-disable-next-line @typescript-eslint/no-explicit-any
jest.mock('components/Content/Content', () => (props: any) => (
  <div id="content">{props.children}</div>
))
const mockStore = configureStore([])

describe('ErrorPage component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ErrorPage text={'test'} returnPage={'ecogestures'} />
      </Provider>
    )

    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should click on button and be redirected', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ErrorPage text={'test'} returnPage={'ecogestures'} />
      </Provider>
    )
    wrapper.find(Button).simulate('click')
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogestures')
  })
})
