import EpglConnectModal from 'components/Connection/PartnerConnectModal/EpglConnectModal'
import { FluidStatus } from 'models'
import React, { useCallback, useState } from 'react'
import '../connection.scss'
import EpglBill from './EpglBill'
import EpglForm from './EpglForm'

interface EpglInitProps {
  fluidStatus: FluidStatus
}

const EpglInit: React.FC<EpglInitProps> = ({ fluidStatus }: EpglInitProps) => {
  const siteLink: string = fluidStatus.connection.konnectorConfig.siteLink

  const [openModal, setOpenModal] = useState(false)
  const [showForm, setShowForm] = useState(false)
  const [hasCreatedAccount, setHasCreatedAccount] = useState(false)

  const toggleModal = useCallback(() => {
    setOpenModal(prev => !prev)
  }, [])

  const goToPartnerSite = useCallback(() => {
    window.open(siteLink, '_blank')
  }, [siteLink])

  return (
    <>
      {!showForm ? (
        <EpglBill togglePartnerConnectionModal={toggleModal} />
      ) : (
        <EpglForm
          fluidStatus={fluidStatus}
          hasCreatedAccount={hasCreatedAccount}
        />
      )}
      <EpglConnectModal
        open={openModal}
        handleCloseClick={toggleModal}
        setShowForm={setShowForm}
        goToPartnerSite={goToPartnerSite}
        setHasCreatedAccount={setHasCreatedAccount}
      />
    </>
  )
}

export default EpglInit
