import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { GlobalState } from 'models/global.model'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import {
  fluidStatusData,
  SgeStatusWithAccount,
} from '../../../../tests/__mocks__/fluidStatusData.mock'
import { globalStateData } from '../../../../tests/__mocks__/globalStateData.mock'
import { waitForComponentToPaint } from '../../../../tests/__mocks__/testUtils'
import SgeInit from './SgeInit'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

const mockConnect = jest.fn()
const mockUpdate = jest.fn()

jest.mock('components/Hooks/useKonnectorAuth', () =>
  jest.fn(() => [mockConnect, mockUpdate])
)
const mockStore = configureStore<{ ecolyo: { global: GlobalState } }>([])

describe('SgeInit component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <SgeInit fluidStatus={fluidStatusData[0]} />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should go to sge connect steps', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <SgeInit fluidStatus={fluidStatusData[0]} />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockedNavigate).toHaveBeenCalled()
  })
  it('should launch account and trigger creation process', async () => {
    const store = mockStore({
      ecolyo: {
        global: {
          ...globalStateData,
          sgeConnect: {
            ...globalStateData.sgeConnect,
            shouldLaunchAccount: true,
          },
        },
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <SgeInit fluidStatus={fluidStatusData[0]} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(mockConnect).toHaveBeenCalled()
  })
  it('should launch existing account update process', async () => {
    const store = mockStore({
      ecolyo: {
        global: {
          ...globalStateData,
          sgeConnect: {
            ...globalStateData.sgeConnect,
            shouldLaunchAccount: true,
          },
        },
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <SgeInit fluidStatus={SgeStatusWithAccount} />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(mockUpdate).toHaveBeenCalled()
  })
})
