import React from 'react'
import { mount } from 'enzyme'
import configureStore from 'redux-mock-store'
import { Provider } from 'react-redux'
import { globalStateData } from '../../../../tests/__mocks__/globalStateData.mock'
import toJson from 'enzyme-to-json'
import StepIdentityAndPdl from './StepIdentityAndPdl'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockStore = configureStore([])

describe('StepIdentityAndPdl component', () => {
  it('should be rendered correctly', () => {
    const mockHandleChange = jest.fn()
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <StepIdentityAndPdl
          sgeState={globalStateData.sgeConnect}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should change firstName value', () => {
    const mockHandleChange = jest.fn()
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <StepIdentityAndPdl
          sgeState={globalStateData.sgeConnect}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    wrapper.find('#firstName').first().simulate('change')
    expect(mockHandleChange).toHaveBeenCalledWith('firstName', '')
  })
  it('should change lastName value', () => {
    const mockHandleChange = jest.fn()
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <StepIdentityAndPdl
          sgeState={globalStateData.sgeConnect}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    wrapper.find('#lastName').first().simulate('change')
    expect(mockHandleChange).toHaveBeenCalledWith('lastName', '')
  })
  it('should change pdl value', () => {
    const mockHandleChange = jest.fn()
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <StepIdentityAndPdl
          sgeState={globalStateData.sgeConnect}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    wrapper.find('#pdl').first().simulate('change')
    expect(mockHandleChange).toHaveBeenCalledWith('pdl', '', 14)
  })
  it('should open hint modal', () => {
    const mockHandleChange = jest.fn()
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <StepIdentityAndPdl
          sgeState={globalStateData.sgeConnect}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    wrapper.find('.pdl-hint').first().simulate('click')
    expect(wrapper.find('.sgeHintModal')).toBeTruthy()
  })
  it('should have an existing pdl value', () => {
    const mockHandleChange = jest.fn()
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <StepIdentityAndPdl
          sgeState={{ ...globalStateData.sgeConnect, pdl: 11111111111111 }}
          onChange={mockHandleChange}
        />
      </Provider>
    )
    expect(wrapper.find('#pdl').first().props().value).toBe(11111111111111)
  })
})
