import DuelOngoing from 'components/Duel/DuelOngoing'
import { UserChallengeState } from 'enum/userChallenge.enum'
import { mount } from 'enzyme'
import { DateTime } from 'luxon'
import { UserChallenge } from 'models'
import React from 'react'
import { act } from 'react-dom/test-utils'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import DuelResultModal from './DuelResultModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockUserChallengeUpdateFlag = jest.fn()
const mockIsChallengeDone = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => {
    return {
      updateUserChallenge: mockUserChallengeUpdateFlag,
      isChallengeDone: mockIsChallengeDone,
    }
  })
})

const mockHistoryPush = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => ({
    push: mockHistoryPush,
  }),
}))
const mockImportIconById = jest.fn()
const mockFormatNumberValues = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
    formatNumberValues: jest.fn(() => {
      return mockFormatNumberValues
    }),
  }
})
jest.mock('components/Duel/DuelChart', () => 'mock-duelchart')
jest.mock('components/Duel/DuelResultModal', () => 'mock-duelModal')

const mockStore = configureStore([])

describe('DuelOngoing component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    mockIsChallengeDone.mockResolvedValue({
      isDone: false,
      isWin: false,
      isEmpty: false,
    })
    mockFormatNumberValues.mockReturnValue('20')
    const wrapper = mount(
      <Provider store={store}>
        <DuelOngoing userChallenge={userChallengeData[0]} />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    expect(wrapper.find('.duel-title').text()).toEqual(
      userChallengeData[1].duel.title
    )
    expect(wrapper.find('.duel-goal').exists()).toBeTruthy()
    expect(wrapper.find('.duel-consumption').exists()).toBeTruthy()
    expect(wrapper.find('.duel-chart').exists()).toBeTruthy()
    expect(wrapper.find('.caption-icon').exists()).toBeTruthy()
  })

  it('should display the result Modal when duel is done', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const updatedUserChallenge: UserChallenge = {
      ...userChallengeData[0],
      state: UserChallengeState.DUEL,
      startDate: DateTime.local().setZone('utc', { keepLocalTime: true }),
    }
    mockIsChallengeDone.mockResolvedValue({
      isDone: true,
      isWin: true,
    })
    mockUserChallengeUpdateFlag.mockResolvedValue(updatedUserChallenge)
    const wrapper = mount(
      <Provider store={store}>
        <DuelOngoing userChallenge={updatedUserChallenge} />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    expect(wrapper.find(DuelResultModal).exists()).toBeTruthy()
  })
})
