import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import EcogestureReinitModal from './EcogestureReinitModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconById = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
  }
})

const mockStore = configureStore([])

describe('EcogestureReinitModal component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <EcogestureReinitModal
          open={true}
          handleCloseClick={jest.fn()}
          handleLaunchReinit={jest.fn()}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
})
