import { IconButton, Tab } from '@material-ui/core'
import EcogestureView from 'components/Ecogesture/EcogestureView'
import { Season } from 'enum/ecogesture.enum'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import * as profileActions from 'store/profile/profile.actions'
import { ecogesturesData } from '../../../tests/__mocks__/ecogesturesData.mock'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import EcogestureEmptyList from './EcogestureEmptyList'
import EcogestureInitModal from './EcogestureInitModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockgetAllEcogestures = jest.fn()
const mockGetEcogestureListByProfile = jest.fn()
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => {
    return {
      getAllEcogestures: mockgetAllEcogestures,
      getEcogestureListByProfile: mockGetEcogestureListByProfile,
    }
  })
})
const mockgetProfile = jest.fn()
const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => {
    return {
      getProfile: mockgetProfile,
      updateProfile: mockUpdateProfile,
    }
  })
})

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Ecogesture/EcogestureList', () => 'mock-ecogesturelist')
jest.mock('components/Content/Content', () => 'mock-content')
const mockgetSeason = jest.fn()
jest.mock('utils/utils', () => {
  return {
    getSeason: jest.fn(() => {
      return mockgetSeason
    }),
  }
})
const useSelectorSpy = jest.spyOn(reactRedux, 'useSelector')
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useLocation: () => {
    return {
      search: '',
    }
  },
  useNavigate: () => mockedNavigate,
}))

describe('EcogestureView component', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
    mockgetSeason.mockClear()
    mockgetAllEcogestures.mockClear()
    mockGetEcogestureListByProfile.mockClear()
  })

  it('should be rendered correctly', async () => {
    useSelectorSpy.mockReturnValue({
      ...mockInitialEcolyoState.profile,
      isProfileTypeCompleted: true,
      haveSeenEcogestureModal: true,
    })
    mockgetSeason.mockReturnValue(Season.WINTER)
    mockgetAllEcogestures.mockResolvedValueOnce(ecogesturesData)
    mockGetEcogestureListByProfile.mockResolvedValue([])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find(Tab).length).toBe(3)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render ecogesture init modal', async () => {
    const updateProfileSpy = jest.spyOn(profileActions, 'updateProfile')

    useSelectorSpy.mockReturnValue({
      ...mockInitialEcolyoState.profile,
      isProfileTypeCompleted: true,
      haveSeenEcogestureModal: false,
    })
    mockgetSeason.mockReturnValue(Season.WINTER)
    mockgetAllEcogestures.mockResolvedValueOnce(ecogesturesData)
    mockGetEcogestureListByProfile.mockResolvedValueOnce([])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find(EcogestureInitModal).exists()).toBeTruthy()
    wrapper.find(IconButton).first().simulate('click')
    await waitForComponentToPaint(wrapper)

    expect(updateProfileSpy).toHaveBeenCalledWith({
      haveSeenEcogestureModal: true,
    })
  })

  it('should render empty list', async () => {
    useSelectorSpy.mockReturnValue({
      ...mockInitialEcolyoState.profile,
      isProfileTypeCompleted: true,
      haveSeenEcogestureModal: false,
    })
    mockgetSeason.mockReturnValue(Season.WINTER)
    mockgetAllEcogestures.mockResolvedValueOnce([])
    mockGetEcogestureListByProfile.mockResolvedValueOnce([])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find(EcogestureEmptyList).exists()).toBeTruthy()
  })
  it('should change tab', async () => {
    useSelectorSpy.mockReturnValue({
      ...mockInitialEcolyoState.profile,
      isProfileTypeCompleted: true,
      haveSeenEcogestureModal: true,
    })
    mockgetSeason.mockReturnValue(Season.WINTER)
    mockgetAllEcogestures.mockResolvedValueOnce(ecogesturesData)
    mockGetEcogestureListByProfile.mockResolvedValueOnce([])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    wrapper.find(Tab).first().simulate('click')
    mockgetAllEcogestures.mockResolvedValueOnce([])

    await waitForComponentToPaint(wrapper)

    expect(wrapper.find(EcogestureEmptyList).exists()).toBeTruthy()
  })
})
