import React from 'react'
import Dialog from '@material-ui/core/Dialog'
import { Button, IconButton } from '@material-ui/core'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import CloseIcon from 'assets/icons/ico/close.svg'
import './ecogestureLaunchFormModal.scss'

interface EcogestureLaunchFormModalProps {
  open: boolean
  handleCloseClick: () => void
}
const EcogestureLaunchFormModal: React.FC<EcogestureLaunchFormModalProps> = ({
  open,
  handleCloseClick,
}: EcogestureLaunchFormModalProps) => {
  const { t } = useI18n()
  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby={'accessibility-title'}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id={'accessibility-title'}>
        {t('feedback.accessibility.window_title')}
      </div>
      <IconButton
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={handleCloseClick}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="eg-init-modal">
        <div className="title text-20-bold">
          {t('ecogesture.initModal.title')}
        </div>
        <div className="text-16-normal text">
          {t('ecogesture.initModal.text3')}
        </div>
        <Button
          aria-label={t('ecogesture.initModal.btn2')}
          onClick={handleCloseClick}
          classes={{
            root: 'btn-profile-next rounded',
            label: 'text-16-bold',
          }}
        >
          {t('ecogesture.initModal.btn2')}
        </Button>
      </div>
    </Dialog>
  )
}

export default EcogestureLaunchFormModal
