import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { DateTime } from 'luxon'
import React from 'react'
import './fluidPerformanceIndicator.scss'

import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { FluidType } from 'enum/fluid.enum'
import { PerformanceIndicator } from 'models'
import { getPicto } from 'utils/picto'
import { formatNumberValues, getPreviousMonthName } from 'utils/utils'

interface FluidPerformanceIndicatorProps {
  performanceIndicator: PerformanceIndicator
  fluidType: FluidType
  date: DateTime
}

const percentSwitch = (percentage: number) => {
  if (percentage > 0) {
    return `+${formatNumberValues(percentage * 100)} %`
  } else if (percentage < 0) {
    return `-${formatNumberValues(Math.abs(percentage) * 100)} %`
  } else {
    return `${formatNumberValues(percentage * 100)} %`
  }
}

const FluidPerformanceIndicator: React.FC<FluidPerformanceIndicatorProps> = ({
  performanceIndicator,
  fluidType,
  date,
}: FluidPerformanceIndicatorProps) => {
  const { t } = useI18n()
  const iconType = getPicto(fluidType)
  let displayedValue = '----'
  if (performanceIndicator?.value) {
    displayedValue = formatNumberValues(performanceIndicator.value).toString()
  }
  return (
    <div className="card">
      <div className="fpi">
        <div className="fpi-left">
          <div className="fpi-content">
            <StyledIcon
              className="fpi-content-icon"
              icon={iconType}
              size={50}
            />
            <div className="fpi-content-perf">
              {!performanceIndicator.value ? (
                <div className="fpi-content-perf-no-data card-result">
                  <span>{t('performance_indicator.fpi.no_data')}</span>
                </div>
              ) : (
                <div className="fpi-content-perf-result card-result">
                  <span>{displayedValue}</span>
                  <span className="card-indicator">
                    {t('FLUID.' + FluidType[fluidType] + '.UNIT')}
                  </span>
                  <span className={`euro-value month`}>
                    {/* condition pas de comparaison possible */}
                    <span
                      className={`${
                        performanceIndicator?.percentageVariation &&
                        performanceIndicator?.percentageVariation >= 0
                          ? 'positive'
                          : 'negative'
                      }`}
                    >
                      {performanceIndicator?.percentageVariation !== null ? (
                        percentSwitch(performanceIndicator.percentageVariation)
                      ) : (
                        <>
                          <span className="no-comparison">
                            {t('performance_indicator.fpi.no_comparison')}
                          </span>
                        </>
                      )}
                    </span>
                    {performanceIndicator.percentageVariation !== null &&
                      `/ ${getPreviousMonthName(date.minus({ month: 1 }))}`}
                  </span>
                </div>
              )}
            </div>
          </div>
        </div>
      </div>
    </div>
  )
}

export default FluidPerformanceIndicator
