import React from 'react'
import { mount } from 'enzyme'
import SplashScreenError from './SplashScreenError'
import Button from '@material-ui/core/Button'
import { InitStepsErrors } from 'models/initialisationSteps.model'
import toJson from 'enzyme-to-json'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

describe('SplashScreenError component', () => {
  const reload = window.location.reload

  beforeAll(() => {
    Object.defineProperty(window, 'location', {
      value: { reload: jest.fn() },
    })
  })

  afterAll(() => {
    window.location.reload = reload
  })
  it('should be rendered correctly', () => {
    const component = mount(
      <SplashScreenError error={InitStepsErrors.CONSENT_ERROR} />
    )
    expect(toJson(component)).toMatchSnapshot()
  })
  it('should reload the page', () => {
    const component = mount(
      <SplashScreenError error={InitStepsErrors.CONSENT_ERROR} />
    )
    component.find(Button).first().simulate('click')
    expect(window.location.reload).toHaveBeenCalled()
  })
})
