import React, { useEffect, useState } from 'react'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import PileIcon from 'assets/icons/ico/coins.svg'
import './totalConsumption.scss'
import { Dataload } from 'models'
import { FluidType } from 'enum/fluid.enum'
import ConverterService from 'services/converter.service'
import { formatNumberValues } from 'utils/utils'
import ConsumptionService from 'services/consumption.service'
import { useClient } from 'cozy-client'
import { TimeStep } from 'enum/timeStep.enum'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'

interface TotalConsumptionProps {
  actualData: Dataload[]
  fluidType: FluidType
}

const TotalConsumption: React.FC<TotalConsumptionProps> = ({
  actualData,
  fluidType,
}: TotalConsumptionProps) => {
  const { currentTimeStep } = useSelector(
    (state: AppStore) => state.ecolyo.chart
  )
  const client = useClient()
  const [totalValue, setTotalValue] = useState<string>()

  useEffect(() => {
    const calculateTotalValue = async () => {
      const consumptionService = new ConsumptionService(client)
      const activateHalfHourLoad =
        fluidType === FluidType.ELECTRICITY
          ? await consumptionService.checkDoctypeEntries(
              FluidType.ELECTRICITY,
              TimeStep.HALF_AN_HOUR
            )
          : false

      const converterService = new ConverterService()
      let total = 0
      let totalPrice = 0

      actualData.forEach(data => {
        if (data.value !== -1) {
          total += data.value
          totalPrice += converterService.LoadToEuro(
            data.value,
            fluidType,
            data.price
          )
        }
      })

      const displayedValue =
        total <= 0 ||
        (!activateHalfHourLoad &&
          currentTimeStep === TimeStep.HALF_AN_HOUR &&
          fluidType === FluidType.ELECTRICITY)
          ? '-----'
          : fluidType === FluidType.MULTIFLUID
          ? formatNumberValues(total).toString()
          : totalPrice <= 0
          ? formatNumberValues(
              converterService.LoadToEuro(total, fluidType)
            ).toString()
          : formatNumberValues(totalPrice).toString()

      setTotalValue(displayedValue)
    }

    calculateTotalValue()
  }, [actualData, fluidType, currentTimeStep, client])

  return (
    <div className="icon-line">
      <StyledIcon className="pile-icon" icon={PileIcon} size={35} />
      <div>
        <span className="euro-value">{totalValue}</span>
        <span className="euro-symbol"> €</span>
      </div>
    </div>
  )
}

export default TotalConsumption
