import {
  HousingType,
  Floor,
  ConstructionYear,
  IndividualInsulationWork,
  HotWaterEquipment,
  OutsideFacingWalls,
  IndividualOrCollective,
  ProfileTypeFormType,
  ThreeChoicesAnswer,
  WarmingType,
} from 'enum/profileType.enum'
import { FluidType } from 'enum/fluid.enum'
import { DateTime } from 'luxon'
import { EquipmentType } from 'enum/ecogesture.enum'

interface ProfileTypeIndexableTypes {
  [key: string]:
    | HousingType
    | ConstructionYear
    | OutsideFacingWalls
    | Floor
    | IndividualOrCollective
    | IndividualInsulationWork[]
    | ThreeChoicesAnswer
    | HotWaterEquipment
    | FluidType
    | DateTime
    | EquipmentType[]
    | number
    | string
    | string[]
    | null
}
export interface ProfileType extends ProfileTypeIndexableTypes {
  housingType: HousingType
  constructionYear: ConstructionYear
  area: string
  occupantsNumber: number
  outsideFacingWalls: OutsideFacingWalls
  floor: Floor
  heating: IndividualOrCollective
  coldWater: IndividualOrCollective
  hotWater: IndividualOrCollective
  individualInsulationWork: IndividualInsulationWork[]
  hasInstalledVentilation: ThreeChoicesAnswer
  hasReplacedHeater: ThreeChoicesAnswer
  hotWaterEquipment: HotWaterEquipment
  warmingFluid: WarmingType | null
  hotWaterFluid: FluidType | null
  cookingFluid: FluidType
  updateDate: DateTime
  equipments: EquipmentType[]
}

export interface MonthlyForecast {
  month: number
  fluidForecast: FluidForecast[]
  totalValue: number
}
export interface FluidForecast {
  fluidType: FluidType
  load: number
  value: number
  detailsMonthlyForecast: DetailsMonthlyForecast
}
export interface DetailsMonthlyForecast {
  heatingConsumption: number | null
  ecsConsumption: number | null
  cookingConsumption: number | null
  electricSpecificConsumption: number | null
  coldWaterConsumption: number | null
}

export type ProfileTypeAnswerChoices =
  | string
  | number
  | HousingType
  | ConstructionYear
  | OutsideFacingWalls
  | Floor
  | IndividualOrCollective
  | IndividualInsulationWork[]
  | ThreeChoicesAnswer
  | HotWaterEquipment
  | FluidType
  | DateTime
  | null
export interface ProfileTypeAnswer {
  type: ProfileTypeFormType
  attribute: string
  choices: ProfileTypeAnswerChoices[]
}
