import { Client } from 'cozy-client'
import { Dispatch } from 'react'
import { AppStore } from 'store'
import { ProfileEcogesture } from 'models/profileEcogesture.model'
import { PROFILEECOGESTURE_DOCTYPE } from 'doctypes/com-grandlyon-ecolyo-profileecogesture'
import ProfileEcogestureService from 'services/profileEcogesture.service'

export const UPDATE_PROFILEECOGESTURE = 'UPDATE_PROFILEECOGESTURE'
export const CREATE_NEW_PROFILEECOGESTURE = 'CREATE_NEW_PROFILEECOGESTURE'

export interface UpdateProfileEcogesture {
  type: typeof UPDATE_PROFILEECOGESTURE
  payload?: ProfileEcogesture
}

export interface CreateNewProfileEcogesture {
  type: typeof CREATE_NEW_PROFILEECOGESTURE
  payload?: ProfileEcogesture
}

export type ProfileEcogestureActionTypes =
  | UpdateProfileEcogesture
  | CreateNewProfileEcogesture

export function updateProfileEcogestureSuccess(
  updatedProfileEcogesture: ProfileEcogesture
): UpdateProfileEcogesture {
  return {
    type: UPDATE_PROFILEECOGESTURE,
    payload: updatedProfileEcogesture,
  }
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export function updateProfileEcogesture(upd: Partial<ProfileEcogesture>): any {
  return async (
    dispatch: Dispatch<UpdateProfileEcogesture>,
    getState: () => AppStore,
    { client }: { client: Client }
  ) => {
    const profileEcogestureService = new ProfileEcogestureService(client)
    const updatedProfileEcogesture =
      await profileEcogestureService.updateProfileEcogesture(upd)
    if (updatedProfileEcogesture) {
      dispatch(updateProfileEcogestureSuccess(updatedProfileEcogesture))
    }
  }
}

export function newProfileEcogestureEntry(
  upd: Partial<ProfileEcogesture>
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
): any {
  return async (
    dispatch: Dispatch<UpdateProfileEcogesture>,
    getState: () => AppStore,
    { client }: { client: Client }
  ) => {
    const { data: newProfileEcogesture } = await client.create(
      PROFILEECOGESTURE_DOCTYPE,
      upd
    )
    if (newProfileEcogesture) {
      dispatch(updateProfileEcogestureSuccess(newProfileEcogesture))
    }
  }
}
