import { Client } from 'cozy-client'
import { ProfileType } from 'models'
import { Dispatch } from 'react'
import { AppStore } from 'store'
import { PROFILETYPE_DOCTYPE } from 'doctypes'
import ProfileTypeEntityService from 'services/profileTypeEntity.service'

export const UPDATE_PROFILETYPE = 'UPDATE_PROFILETYPE'
export const CREATE_NEW_PROFILETYPE = 'CREATE_NEW_PROFILETYPE'

export interface UpdateProfileType {
  type: typeof UPDATE_PROFILETYPE
  payload?: ProfileType
}

export interface CreateNewProfileType {
  type: typeof CREATE_NEW_PROFILETYPE
  payload?: ProfileType
}

export type ProfileTypeActionTypes = UpdateProfileType | CreateNewProfileType

export function updateProfileTypeSuccess(
  updatedProfileType: ProfileType
): UpdateProfileType {
  return {
    type: UPDATE_PROFILETYPE,
    payload: updatedProfileType,
  }
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export function updateProfileType(upd: Partial<ProfileType>): any {
  return async (
    dispatch: Dispatch<UpdateProfileType>,
    getState: () => AppStore,
    { client }: { client: Client }
  ) => {
    const profileTypeEntityService = new ProfileTypeEntityService(client)
    const updatedProfileType = await profileTypeEntityService.updateProfileType(
      upd
    )
    if (updatedProfileType) {
      dispatch(updateProfileTypeSuccess(updatedProfileType))
    }
  }
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export function newProfileTypeEntry(upd: Partial<ProfileType>): any {
  return async (
    dispatch: Dispatch<UpdateProfileType>,
    getState: () => AppStore,
    { client }: { client: Client }
  ) => {
    const { data: newProfileType } = await client.create(
      PROFILETYPE_DOCTYPE,
      upd
    )
    if (newProfileType) {
      dispatch(updateProfileTypeSuccess(newProfileType))
    }
  }
}
